@@ -5,8 +5,6 @@ use strict;
 use Devel::NYTProf::Util qw(strip_prefix_from_paths);
 
 use Devel::NYTProf::Constants qw(
-    NYTP_FIDf_HAS_SRC NYTP_FIDf_SAVE_SRC NYTP_FIDf_IS_FAKE
-
     NYTP_FIDi_FILENAME NYTP_FIDi_EVAL_FID NYTP_FIDi_EVAL_LINE NYTP_FIDi_FID
     NYTP_FIDi_FLAGS NYTP_FIDi_FILESIZE NYTP_FIDi_FILEMTIME NYTP_FIDi_PROFILE
     NYTP_FIDi_EVAL_FI NYTP_FIDi_HAS_EVALS NYTP_FIDi_SUBS_DEFINED NYTP_FIDi_SUBS_CALLED
@@ -14,7 +12,6 @@ use Devel::NYTProf::Constants qw(
 
     NYTP_SCi_CALL_COUNT NYTP_SCi_INCL_RTIME NYTP_SCi_EXCL_RTIME
     NYTP_SCi_INCL_UTIME NYTP_SCi_INCL_STIME NYTP_SCi_RECI_RTIME
-    NYTP_SCi_CALLING_SUB
 );
 
 
@@ -115,18 +112,6 @@ sub is_pmc {
 }
 
 
-sub is_perl_std_lib {
-    my $self = shift;
-    my $filename = $self->filename;
-    my $attributes = $self->profile->attributes;
-    for (@{$attributes}{qw(PRIVLIB_EXP ARCHLIB_EXP)}) {
-        next unless $_;
-        return 1 if $filename =~ /\Q$_/;
-    }
-    return 0;
-}
-
-
 # should return the filename that the application used
 # when loading the file
 sub filename_without_inc {
@@ -142,9 +127,6 @@ sub abs_filename {
 
     my $filename = $self->filename;
 
-    # strip of autosplit annotation, if any
-    $filename =~ s/ \(autosplit into .*//;
-
     # if it's a .pmc then assume that's the file we want to look at
     # (because the main use for .pmc's are related to perl6)
     $filename .= "c" if $self->is_pmc;
@@ -177,15 +159,9 @@ sub srclines_array {
     }
 
     my $filename = $self->abs_filename;
-    if (open my $fh, "<", $filename) {
-        return [ <$fh> ];
-    }
-
-    if ($self->flags & NYTP_FIDf_IS_FAKE) {
-        return [ "# NYTP_FIDf_IS_FAKE - e.g., unknown caller of an eval.\n" ];
-    }
-
-    return undef;
+    open my $fh, "<", $filename
+        or return undef;
+    return [ <$fh> ];
 }
 
 
@@ -195,9 +171,6 @@ sub normalize_for_test {
     # normalize eval sequence numbers in 'file' names to 0
     $self->[NYTP_FIDi_FILENAME] =~ s/ \( ((?:re_)?) eval \s \d+ \) /(${1}eval 0)/xg;
 
-    # normalize flags to avoid failures due to savesrc and perl version
-    $self->[NYTP_FIDi_FLAGS] &= ~(NYTP_FIDf_HAS_SRC|NYTP_FIDf_SAVE_SRC);
-
     for my $sc (map { values %$_ } values %{ $self->sub_call_lines }) {
         $sc->[NYTP_SCi_INCL_RTIME] =
         $sc->[NYTP_SCi_EXCL_RTIME] =
@@ -237,13 +210,12 @@ sub dump {
             my $subs_called = $sub_call_lines->{$line};
 
             for my $subname (sort keys %$subs_called) {
-                my @sc = @{$subs_called->{$subname}};
-                $sc[NYTP_SCi_CALLING_SUB] = join "|", keys %{ $sc[NYTP_SCi_CALLING_SUB] };
+                my $sc = $subs_called->{$subname};
 
                 printf $fh "%s%s%s%s%s%s%s[ %s ]\n", 
                     $prefix, 'call', $separator,
                     $line,  $separator, $subname, $separator,
-                    join(" ", map { defined($_) ? $_ : 'undef' } @sc)
+                    join(" ", map { defined($_) ? $_ : 'undef' } @$sc)
             }
         }
 
